package com.yunzhi.dianyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.dianyang.common.BaseController;
import com.yunzhi.dianyang.common.ResponseBean;
import com.yunzhi.dianyang.common.StringUtils;
import com.yunzhi.dianyang.entity.TaPerson;
import com.yunzhi.dianyang.vo.ChartParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.dianyang.service.ITaPvService;
import com.yunzhi.dianyang.entity.TaPv;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * pv 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-24
 */

@Api(tags = "pv")
@RestController
@RequestMapping("/")
public class TaPvController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPvController.class);

    @Autowired
    public ITaPvService iTaPvService;


    /**
     * 分页查询列表
     * @param startDate
     * @param days
     * @return
     */
    @RequestMapping(value="/admin/pv",method= RequestMethod.GET)
    @ApiOperation(value="PV日统计", notes = "PV日统计", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPvList(@ApiParam(value = "开始日期", example = "2022-02-20") @RequestParam(value ="startDate") String startDate,
                                 @ApiParam("统计天数") @RequestParam(value ="days", defaultValue = "7") Integer days) throws Exception{

        List<ChartParam> result = iTaPvService.statisPVDaily(startDate, days);
        return ResponseBean.success(result);
    }

    /**
     * 分页查询列表
     * @param startDate
     * @param days
     * @return
     */
    @RequestMapping(value="/admin/uv",method= RequestMethod.GET)
    @ApiOperation(value="UV日统计", notes = "UV日统计", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getUV(@ApiParam(value = "开始日期", example = "2022-02-20") @RequestParam(value ="startDate") String startDate,
                              @ApiParam("统计天数") @RequestParam(value ="days", defaultValue = "7") Integer days) throws Exception{

        List<ChartParam> result = iTaPvService.statisUVDaily(startDate, days);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taPv 实体对象
     * @return
     */
    @RequestMapping(value="/wx/pv",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPvAdd(@ApiParam("保存内容") @RequestBody TaPv taPv,
                                HttpServletRequest request) throws Exception{

        if (StringUtils.isEmpty(taPv.getAddr())) {
            return ResponseBean.error("没有埋点数据", ResponseBean.ERROR_UNAVAILABLE);
        }

        TaPerson taPerson = getCurrentPerson(request);
        taPv.setSerailNo(null);
        taPv.setPersonId(taPerson.getPersonId());
        taPv.setCreateDate(LocalDateTime.now());

        if (iTaPvService.save(taPv)){
            return ResponseBean.success(taPv);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

}
