package com.yunzhi.dianyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.dianyang.common.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.dianyang.service.ITaRegisterService;
import com.yunzhi.dianyang.entity.TaRegister;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 报名表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-24
 */

@Api(tags = "报名表")
@RestController
@RequestMapping("/")
public class TaRegisterController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRegisterController.class);

    @Autowired
    public ITaRegisterService iTaRegisterService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/register",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRegisterList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                                       @ApiParam("手机号") @RequestParam(value ="phone", required = false) String phone,
                                       @ApiParam("手机号") @RequestParam(value ="personType", required = false) String personType,
                                       @ApiParam("所属地区") @RequestParam(value ="area", required = false) String area,
                                       @ApiParam(value = "开始时间", example = "2022-02-21") @RequestParam(value ="startDate", required = false) String startDate,
                                       @ApiParam(value = "结束时间", example = "2022-02-28") @RequestParam(value ="endDate", required = false) String endDate) throws Exception{

        LocalDateTime start = null;
        LocalDateTime end = null;
        if ((StringUtils.isEmpty(startDate) && !StringUtils.isEmpty(endDate)) || (!StringUtils.isEmpty(startDate) && StringUtils.isEmpty(endDate))) {
            return ResponseBean.error("请选择完整的开始结束时间", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!StringUtils.isEmpty(startDate)) {
            start = DateUtils.from(startDate + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
            end = DateUtils.from(endDate + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
        }

        IPage<TaRegister> pg = new Page<>(pageNum, pageSize);

        IPage<TaRegister> result = iTaRegisterService.getPageBy(pg, name, phone, personType, area, start, end);
        return ResponseBean.success(result);
    }


    @RequestMapping(value="/admin/register/export",method= RequestMethod.GET)
    @ApiOperation(value="导出", notes = "导出", httpMethod = "GET", response = ResponseBean.class)
    public void export(@ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                       @ApiParam("手机号") @RequestParam(value ="phone", required = false) String phone,
                       @ApiParam("所属地区") @RequestParam(value ="area", required = false) String area,
                       @ApiParam("手机号") @RequestParam(value ="personType", required = false) String personType,
                       @ApiParam(value = "开始时间", example = "2022-02-21") @RequestParam(value ="startDate", required = false) String startDate,
                       @ApiParam(value = "结束时间", example = "2022-02-28") @RequestParam(value ="endDate", required = false) String endDate,
                       HttpServletResponse response) throws Exception {

        LocalDateTime start = null;
        LocalDateTime end = null;
        if ((StringUtils.isEmpty(startDate) && !StringUtils.isEmpty(endDate)) || (!StringUtils.isEmpty(startDate) && StringUtils.isEmpty(endDate))) {
            throw new Exception("请选择完整的开始结束时间");
        }

        if (!StringUtils.isEmpty(startDate)) {
            start = DateUtils.from(startDate + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
            end = DateUtils.from(endDate + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
        }

        List<TaRegister> list = iTaRegisterService.getListBy(name, phone, personType, area, start, end);
        ExcelUtils.flush(response, TaRegister.class, list, "报名人员名单.xlsx");
    }

    /**
     * 保存对象
     * @param taRegister 实体对象
     * @return
     */
    @RequestMapping(value="/wx/register",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taRegisterAdd(@ApiParam("保存内容") @RequestBody TaRegister taRegister) throws Exception{

        if (StringUtils.isEmpty(taRegister.getPhone()) || StringUtils.isEmpty(taRegister.getName())) {
            return ResponseBean.error("报名必填内容不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaRegister exsit = iTaRegisterService.getExistBy("phone", taRegister.getPhone(), true, true);
        if (exsit != null) {
            return ResponseBean.error("当前手机号已经报名", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taRegister.setRegId(null);

        if (iTaRegisterService.save(taRegister)){
            return ResponseBean.success(taRegister);
        } else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taRegister/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taRegisterDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaRegisterService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taRegister 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taRegister/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taRegisterUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaRegister taRegister) throws Exception{
//
//        if (iTaRegisterService.updateById(taRegister)){
//            return ResponseBean.success(iTaRegisterService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/register/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRegisterGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaRegisterService.getById(id));
    }
}
